#!/usr/bin/perl
use strict;
use warnings;
use CGI;
use LWP::UserAgent;
use XML::LibXML;
use JSON::XS;

my $q = CGI->new;

my $issn = $q->param("issn");
my $isbn = $q->param("isbn");

my $url_base = 'http://sfx.scholarsportal.info/laurentian';

my $url_args = '?url_ver=Z39.88-2004&url_ctx_fmt=infofi/fmt:kev:mtx:ctx' .
	'&ctx_enc=UTF-8&ctx_ver=Z39.88-2004&rfr_id=info:sid/conifer' .
	'&sfx.ignore_date_threshold=1&sfx.response_type=multi_obj_detailed_xml' .
	'&__service_type=getFullTxt';

if ($issn) {
	$url_args .= "&rft.issn=$issn";
} elsif ($isbn) {
	$url_args .= "&rft.isbn=$isbn";
}

my $ua = LWP::UserAgent->new;
$ua->agent("SameOrigin/1.0");

my $req = HTTP::Request->new(GET => "$url_base$url_args");
my $res = $ua->request($req);

print $q->header('text/json');
my $xml = $res->content;
my $parser = XML::LibXML->new();
my $parsed_sfx = $parser->parse_string($xml);

my (@targets) = $parsed_sfx->findnodes('//target');

my @sfx_result;
foreach my $target (@targets) {
	my $public_name = $target->findvalue('./target_public_name');
	my $target_url = $target->findvalue('.//target_url');
	my $target_coverage = $target->findvalue('.//coverage_statement');
	my $target_embargo = $target->findvalue('.//embargo_statement');
	push @sfx_result, {
		public_name => $public_name,
		coverage => $target_coverage,
		embargo => $target_embargo,
		url => $target_url
	};
}

print encode_json(\@sfx_result);
